==> versions-maven-plugin-2.17.0-sources.jar: org/codehaus/mojo/versions/reporting/model/PropertyUpdatesModel.java <==
package org.codehaus.mojo.versions.reporting.model;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Map;
import java.util.TreeMap;

import org.codehaus.mojo.versions.api.Property;
import org.codehaus.mojo.versions.api.PropertyVersions;
import org.codehaus.mojo.versions.utils.PropertyComparator;

/**
 * Model class for using with the {@linkplain org.apache.maven.reporting.MavenReportRenderer} API
 */
public class PropertyUpdatesModel {
    private final Map<Property, PropertyVersions> allUpdates;

    public PropertyUpdatesModel(PropertyComparator comparator, Map<Property, PropertyVersions> propertyUpdates) {
        this.allUpdates = new TreeMap<>(comparator);
        this.allUpdates.putAll(propertyUpdates);
    }

    public Map<Property, PropertyVersions> getAllUpdates() {
        return allUpdates;
    }
}

==> versions-maven-plugin-2.20.1-sources.jar: org/codehaus/mojo/versions/reporting/model/PropertyUpdatesModel.java <==
package org.codehaus.mojo.versions.reporting.model;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Map;
import java.util.TreeMap;

import org.codehaus.mojo.versions.api.Property;
import org.codehaus.mojo.versions.api.PropertyVersions;
import org.codehaus.mojo.versions.utils.PropertyComparator;

/**
 * Model class for using with the {@linkplain org.apache.maven.reporting.MavenReportRenderer} API
 */
public class PropertyUpdatesModel {
    private final Map<Property, PropertyVersions> allUpdates;

    /**
     * Creates a new model instance with the given comparator and map of property updates.
     * @param comparator the comparator to use for ordering the properties
     * @param propertyUpdates the map of properties to their updates
     */
    public PropertyUpdatesModel(PropertyComparator comparator, Map<Property, PropertyVersions> propertyUpdates) {
        this.allUpdates = new TreeMap<>(comparator);
        this.allUpdates.putAll(propertyUpdates);
    }

    /**
     * Gets the map of all property updates.
     * @return the map of all property updates
     */
    public Map<Property, PropertyVersions> getAllUpdates() {
        return allUpdates;
    }
}
